@@ -260,7 +260,7 @@ int zmq::socket_poller_t::remove_fd (fd_t fd_)
     return 0;
 }
 
-void zmq::socket_poller_t::rebuild ()
+int zmq::socket_poller_t::rebuild ()
 {
     _use_signaler = false;
     _pollset_size = 0;
@@ -287,10 +287,15 @@ void zmq::socket_poller_t::rebuild ()
     }
 
     if (_pollset_size == 0)
-        return;
+        return 0;
 
     _pollfds = static_cast<pollfd *> (malloc (_pollset_size * sizeof (pollfd)));
-    alloc_assert (_pollfds);
+
+    if (!_pollfds) {
+        errno = ENOMEM;
+        _need_rebuild = true;
+        return -1;
+    }
 
     int item_nbr = 0;
 
@@ -390,6 +395,8 @@ void zmq::socket_poller_t::rebuild ()
     }
 
 #endif
+
+    return 0;
 }
 
 void zmq::socket_poller_t::zero_trail_events (
@@ -523,8 +530,11 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
         return -1;
     }
 
-    if (_need_rebuild)
-        rebuild ();
+    if (_need_rebuild) {
+        int rc = rebuild ();
+        if (rc == -1)
+            return -1;
+    }
 
     if (unlikely (_pollset_size == 0)) {
         // We'll report an error (timed out) as if the list was non-empty and
